@@ -1,3 +1,4 @@
+"""Gather metrics on specific processes"""
 from monagent.collector.checks import AgentCheck
 from monagent.common.util import Platform
 
@@ -37,12 +38,15 @@ class ProcessCheck(AgentCheck):
             for string in search_string:
                 if exact_match:
                     try:
-                        if proc.name == string:
+                        if proc.name() == string:  # psutil >= 2.0
+                            found = True
+                    except TypeError:
+                        if proc.name == string:  # psutil < 2.0
                             found = True
                     except psutil.NoSuchProcess:
                         self.log.warning('Process disappeared while scanning')
                         pass
-                    except psutil.AccessDenied, e:
+                    except psutil.AccessDenied as e:
                         self.log.error('Access denied to %s process' % string)
                         self.log.error('Error: %s' % e)
                         raise
@@ -60,7 +64,8 @@ class ProcessCheck(AgentCheck):
                             self.warning('Process disappeared while scanning')
                             pass
                         except psutil.AccessDenied, e:
-                            self.log.error('Access denied to %s process' % string)
+                            self.log.error('Access denied to %s process'
+                                           % string)
                             self.log.error('Error: %s' % e)
                             raise
 
@@ -79,8 +84,8 @@ class ProcessCheck(AgentCheck):
         thr = 0
 
         # process metrics available for psutil versions 0.6.0 and later
-        extended_metrics_0_6_0 = self.is_psutil_version_later_than((0, 6, 0)) and \
-            not Platform.is_win32()
+        extended_metrics_0_6_0 = (self.is_psutil_version_later_than((0, 6, 0))
+                                  and not Platform.is_win32())
         # On Windows get_ext_memory_info returns different metrics
         if extended_metrics_0_6_0:
             real = 0
@@ -92,8 +97,8 @@ class ProcessCheck(AgentCheck):
             involuntary_ctx_switches = None
 
         # process metrics available for psutil versions 0.5.0 and later on UNIX
-        extended_metrics_0_5_0_unix = self.is_psutil_version_later_than((0, 5, 0)) and \
-                                Platform.is_unix()
+        extended_metrics_0_5_0_unix = (self.is_psutil_version_later_than((0, 5, 0))
+                                       and Platform.is_unix())
         if extended_metrics_0_5_0_unix:
             open_file_descriptors = 0
         else:
@@ -135,8 +140,7 @@ class ProcessCheck(AgentCheck):
                 thr += p.get_num_threads()
                 cpu += p.get_cpu_percent(cpu_check_interval)
 
-                # user agent might not have permission to call get_io_counters()
-                # user agent might have access to io counters for some processes and not others
+                # user might not have permission to call get_io_counters()
                 if read_count is not None:
                     try:
                         io_counters = p.get_io_counters()
@@ -145,8 +149,9 @@ class ProcessCheck(AgentCheck):
                         read_bytes += io_counters.read_bytes
                         write_bytes += io_counters.write_bytes
                     except psutil.AccessDenied:
-                        self.log.info('mon-agent user agent does not have access \
-                            to I/O counters for process %d: %s' % (pid, p.name))
+                        self.log.debug('mon-agent user does not have access ' +
+                                       'to I/O counters for process %d: %s'
+                                       % (pid, p.name))
                         read_count = None
                         write_count = None
                         read_bytes = None
@@ -158,11 +163,13 @@ class ProcessCheck(AgentCheck):
                 pass
 
         if got_denied:
-            self.warning("The Monitoring Agent was denied access when trying to get the number of file descriptors")
+            self.warning("The Monitoring Agent was denied access",
+                         "when trying to get the number of file descriptors")
 
-        #Memory values are in Byte
+        # Memory values are in Byte
         return (thr, cpu, rss, vms, real, open_file_descriptors,
-            read_count, write_count, read_bytes, write_bytes, voluntary_ctx_switches, involuntary_ctx_switches)
+                read_count, write_count, read_bytes, write_bytes,
+                voluntary_ctx_switches, involuntary_ctx_switches)
 
     def check(self, instance):
         try:
@@ -183,7 +190,7 @@ class ProcessCheck(AgentCheck):
             raise KeyError('The "search_string" is mandatory')
 
         if not isinstance(cpu_check_interval, (int, long, float)):
-            self.warning("cpu_check_interval must be a number. Defaulting to 0.1")
+            self.warning("cpu_check_interval not a number; defaulting to 0.1")
             cpu_check_interval = 0.1
 
         pids = self.find_pids(search_string, psutil, exact_match=exact_match)
@@ -193,8 +200,10 @@ class ProcessCheck(AgentCheck):
 
         self.gauge('processes_pid_count', len(pids), dimensions=dimensions)
 
-        metrics = dict(zip(ProcessCheck.PROCESS_GAUGE, self.get_process_metrics(pids,
-            psutil, cpu_check_interval)))
+        metrics = dict(zip(ProcessCheck.PROCESS_GAUGE,
+                           self.get_process_metrics(pids,
+                                                    psutil,
+                                                    cpu_check_interval)))
 
         for metric, value in metrics.iteritems():
             if value is not None:
